@@ -43,6 +43,7 @@ class User {
 	// updateUser
 	// insertLanguages
 	// createPassword
+	// insertProfile
 	// updateProfile
 	// createFeedPassword
 	// selUserPreferences
@@ -50,6 +51,8 @@ class User {
 	// insertUserPreference
 	// deleteUserPreference
 	// selUsers
+	// updateProfileDefaults
+	// deleteProfile
 
 
 
@@ -96,16 +99,20 @@ class User {
 					user_email=" . $this->db->qstr($email, get_magic_quotes_gpc()) . " AND
 					user_password=" . $this->db->qstr(MD5($password), get_magic_quotes_gpc())
 				;
-
-				
 				
 				$result = $this->db->Execute($query);
 
 				if(empty($result->fields['user_id'])) {
 					$GLOBALS['am_error_log'][] = array(19, null, null);
 				}
-
-				if($result->fields['status_id'] != $this->status_ids['active']) {
+				
+				// is the user dormant?
+				if ($result->fields['status_id'] == $this->status_ids['dormant']) {
+					header("Location: spl_view.php?dormant=1");
+					exit;
+				}
+				
+				if ($result->fields['status_id'] != $this->status_ids['active']) {
 					$GLOBALS['am_error_log'][] = array(26, null, null);
 				}
 			}
@@ -136,6 +143,7 @@ class User {
 		if (isset($result->fields['user_id'])){
 			// Starts a session
 			if (empty($_SESSION)) {
+				session_name($this->php_session_name);
 			    session_start();
 			}
 			
@@ -150,7 +158,7 @@ class User {
 			$_SESSION['s_md5'] = 				md5($result->fields['session_id']);
 			$_SESSION['language_id'] = 		$result->fields['language_id'];
 			$_SESSION['user_homepage'] = 		$result->fields['user_homepage'];
-			$_SESSION['user_template_id'] = 	$result->fields['template_title'];
+			$_SESSION['template_id'] = 		$result->fields['template_title'];
 			$_SESSION['breadcrumb'] = 			array();
 			$_SESSION['language_ids'] = 		$this->getLanguages();
 			$_SESSION['user_feed_password'] = 	$result->fields['user_feed_password'];
@@ -188,7 +196,9 @@ class User {
 				if (isset($_SESSION['language_id'])) {
 				    $this->setLocale($_SESSION['language_id']);
 				}
-
+				
+				session_write_close();
+				
 				//did we refer from a local page?
 				if (!empty($this->http_referer)) {
 					return header("Location: " . $this->http_referer);
@@ -227,6 +237,7 @@ class User {
 
 	function logoffUser () {
 		if (!isset($_SESSION)) {
+			session_name($this->php_session_name);
 		    session_start();
 		}
 
@@ -249,28 +260,33 @@ class User {
 			WHERE user_id = " . $_SESSION['s_user_id'] . "
 			order by session_id desc"
 		;
-
+		
 		$result = $this->db->SelectLimit($query, 1);
-
+		
 		// Checks if the session-id in the database and in the session-variables agree
 		if($result->fields['session_md5'] != $_SESSION['s_md5']) {
 			$this->logoffUser();
 			header("Location: index.php?http_referer=" . urlencode($_SERVER['REQUEST_URI']) . "&" . strip_tags(SID));
 			exit;
 		}
-
-
+		
 		// Check if user is locked
 		$query = "
 			SELECT status_id FROM " . $this->db->prefix . "_user
 			WHERE
 			user_id = " . $_SESSION['s_user_id']
 		;
-
+		
 		$result = $this->db->Execute($query);
-
+		
+		// is the user dormant?
+		if ($result->fields['status_id'] == $this->status_ids['dormant']) {
+			header("Location: spl_view.php?dormant=1");
+			exit;
+		}
+		
 		// If user is not active...
-		if($result->fields['status_id'] != $this->status_ids['active']) {
+		if ($result->fields['status_id'] != $this->status_ids['active']) {
 			header("Location: index.php?http_referer=" . urlencode($_SERVER['REQUEST_URI']) . "&" . strip_tags(SID));
 			exit;
 		}
@@ -306,12 +322,12 @@ class User {
 		$result = $this->db->Execute($query);
 		
 		
-		// Logging out people who have not been active for 12 hours - they wil be directed
+		// Logging out people who have not been active for 12 hours - they will be directed
 		// to the login-page as their session-id will not match the database session-id
 		$logout_timestamp = mktime()-(720*60);
 
 		$query = "
-			SELECT user_id
+			SELECT user_id 
 			FROM " . $this->db->prefix . "_user
 			WHERE " . $logout_timestamp . " > active_time"
 		;
@@ -485,12 +501,22 @@ class User {
 		    $url .= "invitee=" . $this->user_id;
 		}
 		
-		$body_file_txt = utf8_decode($body_file_txt);
-		
 		$body_file_txt = str_replace("SYS_KEYWORD_URL", $url, $body_file_txt);
-
-		//send email to barnraiser
-		$this->mail->Body = $body_file_txt;
+		
+		// HTML-version of the mail
+		$html  = "<HTML><HEAD><TITLE></TITLE></HEAD>";
+		$html .= "<BODY>";
+		$html .= utf8_decode($body_file_txt);
+		$html .= "</BODY></HTML>";
+		
+		$alt_body = strip_tags($body_file_txt);
+		
+		// Clear all addresses for next loop
+		$this->mail->ClearAddresses();
+		
+		//send email
+		$this->mail->Body = nl2br($html);
+		$this->mail->AltBody   = utf8_decode($alt_body);
 		$this->mail->AddAddress($email, $firstname);
 
 		if(!$this->mail->Send()) {
@@ -996,9 +1022,12 @@ class User {
 	function updateProfile($data) {
 		if(!empty($data['profile_true_self'])) { // true self
 			
-			if (empty($data['user_hometown'])) {
+			if (empty($data['profile_hometown'])) {
 				$GLOBALS['am_error_log'][] = array(10, null, null);
 			}
+			else {
+				$data['user_hometown'] = $data['profile_hometown'];
+			}
 			
 			if (empty($data['user_firstname'])) {
 				$GLOBALS['am_error_log'][] = array(5, null, null);
@@ -1008,6 +1037,10 @@ class User {
 				$GLOBALS['am_error_log'][] = array(6, null, null);
 			}
 			
+			if (empty($data['profile_nic'])) {
+				$GLOBALS['am_error_log'][] = array(7, null, null);
+			}
+			
 			if (empty($GLOBALS['am_error_log'])) {
 				$query = "
 					SELECT * FROM " . $this->db->prefix . "_user 
@@ -1035,6 +1068,7 @@ class User {
 				$GLOBALS['am_error_log'][] = array(7, null, null);
 			}
 			
+			
 			if (empty($data['profile_hometown'])) {
 				$GLOBALS['am_error_log'][] = array(10, null, null);
 			}
@@ -1075,7 +1109,7 @@ class User {
 			}
 
 			if (empty($data['profile_text6'])) {
-			    $data['profile_text6'] = null;
+			    $data['profile_text6'] = "null";
 			}
 
 			if (empty($data['profile_text7'])) {
@@ -1170,7 +1204,7 @@ class User {
 	function selUserPreferences() {
 		
 		$query = "
-			SELECT user_id, user_preference_id 
+			SELECT user_id, user_preference_id, user_preference_value 
 			FROM " . $this->db->prefix . "_user_preference "
 		;
 		
@@ -1208,10 +1242,10 @@ class User {
 	// returns a user preference
 	// tom calthrop - 27th August 2005
 	//
-	function selUserPreference($user_id, $user_preference_id) {
+	function selUserPreference($user_id, $user_preference_id, $full=null) {
 		
 		$query = "
-			SELECT user_preference_id 
+			SELECT user_preference_id, user_preference_value 
 			FROM " . $this->db->prefix . "_user_preference 
 			WHERE 
 			user_id=" . $user_id . " AND 
@@ -1221,7 +1255,12 @@ class User {
 		$result = $this->db->SelectLimit($query, 1); //returns last 1 rows
 		
 		if (isset($result->fields['user_preference_id'])) {
-			return true;
+			if (isset($full)) {
+				return $result->fields;
+			}
+			else {
+				return true;
+			}
 		}
 		else {
 			return false;
@@ -1234,7 +1273,7 @@ class User {
 	// inserts a users preference
 	// tom calthrop - 27th August 2005
 	//
-	function insertUserPreference($user_preference_id, $user_id = null) {
+	function insertUserPreference($user_preference_id, $user_id = null, $user_preference_value=null) {
 		
 		if (!isset($user_id)) {
 			$user_id = $this->$user_id;
@@ -1243,6 +1282,11 @@ class User {
 		$rec = array();
 		$rec['user_id'] = $user_id;
 		$rec['user_preference_id'] = $user_preference_id;
+		
+		if (isset($user_preference_value) && $user_preference_value>1) {
+			$rec['user_preference_value'] = $user_preference_value;
+		}
+		
 		$table = $this->db->prefix . "_user_preference";
 		
 		$query = $this->db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
@@ -1259,15 +1303,22 @@ class User {
 	// deletes a users preference
 	// tom calthrop - 27th August 2005
 	//
-	function deletetUserPreference($user_preference_id) {
+	function deletetUserPreference($user_preference_id=null, $user_id=null) {
+		
+		if (!isset($user_id)) {
+			$user_id = $this->$user_id;
+		}
 		
 		$query = "
 			DELETE FROM " . $this->db->prefix . "_user_preference 
 			WHERE
-			user_id=" . $this->user_id . " AND 
-			user_preference_id=" . $user_preference_id
+			user_id=" . $user_id
 		;
 		
+		if (isset($user_preference_id)) {
+			$query .= " AND user_preference_id=" . $user_preference_id;
+		}
+		
 		$result = $this->db->Execute($query);
 		
 		if (empty($result)) {
@@ -1281,7 +1332,7 @@ class User {
 	// returns all rows from users - only use if in admin section
 	// tom calthrop - 7th December 2004
 	//
-	function selUsers($tag=null) {
+	function selUsers($tag=null, $directory=null, $search=null) {
 		
 		$query = "
 			SELECT u.user_id, u.user_firstname, u.user_surname, u.active_time, 
@@ -1292,11 +1343,15 @@ class User {
 			;
 		
 		$query .= " JOIN " . $this->db->prefix . "_user_profile p ON u.user_id=p.user_id AND p.profile_default=1 ";
-
+		
 		if (isset($tag)) {
-			$query .= ", " . $this->db->prefix . "_tag t  ";
+			$query .= ", " . $this->db->prefix . "_tag t ";
 		}
-
+		
+		if (isset($directory)) {
+			$query .= ", " . $this->db->prefix . "_user_preference up ";
+		}
+		
 		$query .= "	WHERE ";
 			
 		if (isset($this->status_ids)) {
@@ -1312,6 +1367,17 @@ class User {
 			;
 		}
 		
+		if (isset($directory)) {
+			$query .= "up.user_preference_id=".$directory." AND up.user_id=u.user_id AND ";
+		}
+		
+		if (isset($search)) {
+			$query .= "(
+				p.profile_nic like " . $this->db->qstr("%" . $search . "%", get_magic_quotes_gpc()) . " OR 
+				p.profile_hometown like " . $this->db->qstr("%" . $search . "%", get_magic_quotes_gpc()) . ") AND "
+			;
+		}
+		
 		if (isset($this->user_ids)) {
 			$user_ids = "";
 			foreach($this->user_ids as $key => $i):
@@ -1365,6 +1431,12 @@ class User {
 						$temp1['image']['file'] = $this->file->noimage;
 					}
 				}
+
+				//format search results
+				if (isset($search)) {
+					$temp1['profile_nic'] = searchTextFormat($search, $temp1['profile_nic']);
+					$temp1['profile_hometown'] = searchTextFormat($search, $temp1['profile_hometown']);
+				}
 				
 				array_push($temp, $temp1);
 				$result->MoveNext();
@@ -1409,4 +1481,87 @@ class User {
 			return false;
 		}
 	}
+
+
+
+	// updateProfileDefaults --------------------------------------------------------------------
+	// updates the DB with the default profile ID / true self id
+	// tom calthrop - 22nd December 2004
+	//
+	function updateProfileDefaults($data) {
+		
+		$query = "
+			SELECT * FROM " . $this->db->prefix . "_user_profile 
+			WHERE 
+			user_id=" . $this->user_id
+		;
+		
+		$profiles_result = $this->db->Execute($query);
+		
+		if (isset($data['profile_default'])) {
+			$rec = array();
+			$rec['profile_default'] = "null";
+			
+			$query = $this->db->GetUpdateSQL($profiles_result, $rec, false, get_magic_quotes_gpc());
+			$result = $this->db->Execute($query);
+			
+			$query = "
+				SELECT * FROM " . $this->db->prefix . "_user_profile 
+				WHERE 
+				profile_id=" . $data['profile_default']
+			;
+		
+			$result = $this->db->Execute($query);
+			
+			$rec = array();
+			$rec['profile_default'] = 1;
+
+			$query = $this->db->GetUpdateSQL($result, $rec, false, get_magic_quotes_gpc());
+			$result = $this->db->Execute($query);
+		}
+		
+		if (isset($data['profile_true_self'])) {
+			$rec = array();
+			$rec['profile_true_self'] = "null";
+			
+			$query = $this->db->GetUpdateSQL($profiles_result, $rec, false, get_magic_quotes_gpc());
+			$result = $this->db->Execute($query);
+			
+			$query = "
+				SELECT * FROM " . $this->db->prefix . "_user_profile 
+				WHERE 
+				profile_id=" . $data['profile_true_self']
+			;
+		
+			$result = $this->db->Execute($query);
+			
+			$rec = array();
+			$rec['profile_true_self'] = 1;
+
+			$query = $this->db->GetUpdateSQL($result, $rec, false, get_magic_quotes_gpc());
+			$result = $this->db->Execute($query);
+		}
+	}//EO updateProfileDefaults
+
+
+
+	// deleteProfile --------------------------------------------------------------------
+	// deletes a profile
+	// tom calthrop - 27th December 2004
+	//
+	function deleteProfile($profile_id) {
+
+		$query = "
+			DELETE FROM " . $this->db->prefix . "_user_profile
+			WHERE
+			profile_id=" . $profile_id
+		;
+
+		$result = $this->db->Execute($query);
+
+		if (empty($result)) {
+			$error_info = "function=deleteProfile class=User.class.php -- " . $query . " -- " . $this->db->ErrorMsg();
+			$GLOBALS['am_error_log'][] = array(1, 1, $error_info);
+		}
+	}//EO deleteProfile
 }
